@@ -6,7 +6,9 @@
 #' @details
 #' Given a numeric vector, \code{mean_sd} will return a character string with
 #' the mean and standard deviation.  Formating of the output will be extended in
-#' future versions.
+#' future versions.  
+#'
+#' \code{gmean_sd} returns the geometric mean and geometric standard deviation.
 #'
 #' @param x a numeric vector
 #' @param digits digits to the right of the decimal point to return in the
@@ -59,3 +61,40 @@ mean_sd <- function(x,
   return(rtn)
 }
 
+#' @rdname mean_sd
+#' @export   
+#' @param logged if TRUE the \code{x} is assumed to already by log transformed.
+#' If FALSE the data will be transformed.
+gmean_sd <- function(x, 
+                     logged = FALSE,
+                     digits = getOption("qwraps2_frmt_digits", 2), 
+                     na_rm = FALSE, 
+                     show_n = "ifNA", 
+                     denote_sd = "pm", 
+                     markup = getOption("qwraps2_markup", "latex")) { 
+  n <- sum(!is.na(x))
+
+  if (logged) {
+    m <- exp(mean(x, na.rm = na_rm))
+    s <- sqrt(sum(exp(x)/m, na.rm = na_rm) / n)
+  } else { 
+    m <- exp(mean(log(x), na.rm = na_rm))
+    s <- sqrt(sum(x/m) / n)
+  }
+
+  if (show_n =="always" | any(is.na(x))) { 
+    rtn <- paste0(frmt(as.integer(n), digits), "; ", frmt(m, digits), " $\\pm$ ", frmt(s, digits))
+  } else { 
+    rtn <- paste0(frmt(m, digits), " $\\pm$ ", frmt(s, digits))
+  }
+
+  if (denote_sd == "paren") { 
+    rtn <- gsub("\\$\\\\pm\\$\\s(.*)", "\\(\\1\\)", rtn)
+  }
+
+  if (markup == "markdown") { 
+    rtn <- gsub("\\$\\\\pm\\$", "&plusmn;", rtn)
+  }
+
+  return(rtn)
+}
